@@ -25,16 +25,21 @@
 #' \item Use the \code{shapiro.test} for testing normality assumption with Shapiro-Wilk 
 #' \item Use \code{ggplot2} to plot an interaction plot of the type the user specified }
 #' 
-#' @usage Plot2WayANOVA(formula, dataframe = NULL, confidence=.95, plottype = "bar")
+#' @usage Plot2WayANOVA(formula, dataframe = NULL, confidence=.95, 
+#'     plottype = "bar", PlotSave = FALSE)
 #' @param formula a valid R formula with a numeric dependent (outcome)
 #' variable, and two independent (predictor) variables e.g. \code{mpg~am*vs}.
 #' The independent variables are forced to factors (with warning) if possible.
 #' @param dataframe a dataframe or an object that can be coerced to a dataframe
 #' @param confidence what confidence level for confidence intervals
 #' @param plottype bar or line (quoted)
-#' @return An object of class 'ggplot' which can be saved for future use.  The
-#' most interesting sub element in the list is $data which contains the means
-#' table for the dependent variable grouped by independent variables.
+#' @param PlotSave a logical indicating whether the user wants to save the plot as a png file
+#' @return A list with 4 elements which is returned invisibly. The items are always sent 
+#' to the console for display  The plot is always sent to the default plot device
+#' but for user convenience the function also returns a named list with the following items
+#' in case the user desires to save them or further process them. \code{$ANOVATable}, 
+#' \code{$MeansTable}, \code{$BFTest}, and \code{$SWTest}. 
+#'
 #' @author Chuck Powell
 #' @seealso \code{\link[stats]{aov}}, \code{\link[car]{leveneTest}},
 #' \code{\link{neweta}}, \code{\link[stats]{replications}},
@@ -44,7 +49,7 @@
 #' Plot2WayANOVA(mpg~am*cyl, mtcars, plottype = "line")
 #' Plot2WayANOVA(mpg~am*vs, mtcars, confidence = .99)
 #' 
-#' @import dplyr
+#' @importFrom dplyr group_by summarise %>% n
 #' @import ggplot2
 #' @import rlang
 #' @importFrom methods is
@@ -53,9 +58,8 @@
 #' @importFrom car leveneTest
 #' @export
 #' 
-# works March 14, 2018
-# Stable version 0.1
-Plot2WayANOVA <- function(formula, dataframe = NULL, confidence=.95, plottype = "bar")
+# Stable version 0.2
+Plot2WayANOVA <- function(formula, dataframe = NULL, confidence=.95, plottype = "bar", PlotSave = FALSE)
 {
   # to appease R CMD Check?
   TheMean <- NULL
@@ -91,9 +95,12 @@ Plot2WayANOVA <- function(formula, dataframe = NULL, confidence=.95, plottype =
     stop("invalid value for \"formula\" argument")
   if ("+" %in% chkinter)
     stop("Sorry you need to use an asterisk not a plus sign in the formula so the interaction can be plotted")
+  if ("~" == chkinter[2])
+    stop("Sorry you can only have one dependent variable so only one ~ you have two or more")
   depvar <- vars[1]
   iv1 <- vars[2]
   iv2 <- vars[3]
+  potentialfname <- paste0(depvar,"by",iv1,"and",iv2,".png")
   if (missing(dataframe))
     stop("You didn't specify a data frame to use")
   if (!exists(deparse(substitute(dataframe))))
@@ -196,10 +203,13 @@ Plot2WayANOVA <- function(formula, dataframe = NULL, confidence=.95, plottype =
   }
   print(SWTest)
   message("\nInteraction graph plotted...")
-#  print(p)
-#  return(as.list(c(MyPlot=p$data,ANOVE=WithETA)))
-  return(p)
-  #  return(as.data.frame(newdata))
+  print(p)
+  whattoreturn <- list(ANOVATable = WithETA, MeansTable = newdata, BFTest = BFTest, SWTest = SWTest)
+  if (PlotSave) {
+    ggsave(potentialfname,device = "png")
+    whattoreturn <- list(ANOVATable = WithETA, MeansTable = newdata, BFTest = BFTest, SWTest = SWTest, pFileName = potentialfname)
+  }
+  return(invisible(whattoreturn))
 }
 
 
